==> jc-1.4.0.tar.gz: soot/tagkit/ConstantValueTag.h <==
// public abstract class soot.tagkit.ConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_ConstantValueTag_H_
#define _JC_soot_tagkit_ConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_ConstantValueTag$sub_refs	_jc_soot_tagkit_ConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	_jc_soot_tagkit_ConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_ConstantValueTag$refs	_jc_soot_tagkit_ConstantValueTag$refs;
typedef struct _jc_soot_tagkit_ConstantValueTag$nonrefs	_jc_soot_tagkit_ConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_ConstantValueTag$object	_jc_soot_tagkit_ConstantValueTag$object;

typedef const struct _jc_soot_tagkit_ConstantValueTag$vmethods	_jc_soot_tagkit_ConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_ConstantValueTag$vtable	_jc_soot_tagkit_ConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_ConstantValueTag$vtype	_jc_soot_tagkit_ConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329;

// Virtual methods structure
struct _jc_soot_tagkit_ConstantValueTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_ConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_ConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_ConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_ConstantValueTag$sub_refs {
	_jc_byte_array	*bytes;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_ConstantValueTag$refs {
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_ConstantValueTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_ConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_ConstantValueTag$object {
	_jc_soot_tagkit_ConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_ConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_ConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_ConstantValueTag$vtype _jc_soot_tagkit_ConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_ConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_ConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_ConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/ConstantValueTag.h <==
// public abstract class soot.tagkit.ConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_ConstantValueTag_H_
#define _JC_soot_tagkit_ConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_ConstantValueTag$sub_refs	_jc_soot_tagkit_ConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	_jc_soot_tagkit_ConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_ConstantValueTag$refs	_jc_soot_tagkit_ConstantValueTag$refs;
typedef struct _jc_soot_tagkit_ConstantValueTag$nonrefs	_jc_soot_tagkit_ConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_ConstantValueTag$object	_jc_soot_tagkit_ConstantValueTag$object;

typedef const struct _jc_soot_tagkit_ConstantValueTag$vmethods	_jc_soot_tagkit_ConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_ConstantValueTag$vtable	_jc_soot_tagkit_ConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_ConstantValueTag$vtype	_jc_soot_tagkit_ConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329;

// Virtual methods structure
struct _jc_soot_tagkit_ConstantValueTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_ConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_ConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_ConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_ConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_ConstantValueTag$sub_refs {
	_jc_byte_array	*bytes;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_ConstantValueTag$refs {
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_ConstantValueTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_ConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_ConstantValueTag$object {
	_jc_soot_tagkit_ConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_ConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_ConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_ConstantValueTag$vtype _jc_soot_tagkit_ConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_ConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_ConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_ConstantValueTag_H_ */
